summaryrefslogtreecommitdiffstats
path: root/sandbox/travelsample/contributions/tripbooking
diff options
context:
space:
mode:
authornash <nash@13f79535-47bb-0310-9956-ffa450edef68>2009-08-27 01:07:30 +0000
committernash <nash@13f79535-47bb-0310-9956-ffa450edef68>2009-08-27 01:07:30 +0000
commit47d7bf03613dfd6a2db848df57306c0c2b8c2402 (patch)
tree47d5bc9c7e565ffc5f1a653c2ba2d3cc2df1a940 /sandbox/travelsample/contributions/tripbooking
parente55e032a7fbf42b17461e4fa4ad729b8f58a0f60 (diff)
Apply the new naming conventions to the fullapp contributions and launchers
git-svn-id: http://svn.us.apache.org/repos/asf/tuscany@808241 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to '')
-rw-r--r--sandbox/travelsample/contributions/tripbooking-contribution/build.xml61
-rw-r--r--sandbox/travelsample/contributions/tripbooking-contribution/src/main/resources/META-INF/sca-contribution.xml25
-rw-r--r--sandbox/travelsample/contributions/tripbooking/pom.xml (renamed from sandbox/travelsample/contributions/tripbooking-contribution/pom.xml)8
-rw-r--r--sandbox/travelsample/contributions/tripbooking/src/main/java/com/tuscanyscatours/tripbooking/TripBooking.java (renamed from sandbox/travelsample/contributions/tripbooking-contribution/src/main/java/scatours/tripbooking/TripBooking.java)6
-rw-r--r--sandbox/travelsample/contributions/tripbooking/src/main/java/com/tuscanyscatours/tripbooking/impl/TripBookingImpl.java (renamed from sandbox/travelsample/contributions/tripbooking-contribution/src/main/java/scatours/tripbooking/TripBookingImpl.java)11
-rw-r--r--sandbox/travelsample/contributions/tripbooking/src/main/resources/META-INF/sca-contribution.xml26
6 files changed, 39 insertions, 98 deletions
diff --git a/sandbox/travelsample/contributions/tripbooking-contribution/build.xml b/sandbox/travelsample/contributions/tripbooking-contribution/build.xml
deleted file mode 100644
index 911a648295..0000000000
--- a/sandbox/travelsample/contributions/tripbooking-contribution/build.xml
+++ /dev/null
@@ -1,61 +0,0 @@
-<!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
--->
-<project name="scatours-tripbooking-contribution" default="compile">
- <property environment="env"/>
-
- <target name="compile">
- <mkdir dir="target/classes"/>
- <javac srcdir="src" destdir="target/classes"
- debug="on" source="1.5" target="1.5">
- <classpath>
- <pathelement location="${env.TUSCANY}/lib/tuscany-sca-manifest.jar"/>
- </classpath>
- </javac>
- </target>
-
- <target name="run">
- <java classname="client.CurrencyConverterClient" fork="true">
- <classpath>
- <pathelement path="src"/>
- <pathelement path="target/classes"/>
- <pathelement location="${env.TUSCANY}/lib/tuscany-sca-manifest.jar"/>
- </classpath>
- </java>
- </target>
-
- <target name="runtrip">
- <java classname="client.TripClient" fork="true">
- <classpath>
- <pathelement path="src"/>
- <pathelement path="target/classes"/>
- <pathelement location="${env.TUSCANY}/lib/tuscany-sca-manifest.jar"/>
- </classpath>
- </java>
- </target>
-
- <target name="runtripws">
- <java classname="client.TripWsClient" fork="true">
- <classpath>
- <pathelement path="src"/>
- <pathelement path="target/classes"/>
- <pathelement location="${env.TUSCANY}/lib/tuscany-sca-manifest.jar"/>
- </classpath>
- </java>
- </target>
-</project>
diff --git a/sandbox/travelsample/contributions/tripbooking-contribution/src/main/resources/META-INF/sca-contribution.xml b/sandbox/travelsample/contributions/tripbooking-contribution/src/main/resources/META-INF/sca-contribution.xml
deleted file mode 100644
index b8f57ddbd0..0000000000
--- a/sandbox/travelsample/contributions/tripbooking-contribution/src/main/resources/META-INF/sca-contribution.xml
+++ /dev/null
@@ -1,25 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
--->
-<contribution xmlns="http://www.osoa.org/xmlns/sca/1.0">
- <import.java package="scatours.common"/>
- <import.java package="scatours.currencyconverter"/>
- <import.java package="scatours.shoppingcart"/>
- <export.java package="scatours.tripbooking"/>
-</contribution> \ No newline at end of file
diff --git a/sandbox/travelsample/contributions/tripbooking-contribution/pom.xml b/sandbox/travelsample/contributions/tripbooking/pom.xml
index 108cefb53f..3403fdfbc6 100644
--- a/sandbox/travelsample/contributions/tripbooking-contribution/pom.xml
+++ b/sandbox/travelsample/contributions/tripbooking/pom.xml
@@ -25,7 +25,7 @@
<version>1.6-SNAPSHOT</version>
<!--relativePath>../../pom.xml</relativePath-->
</parent><version>1.0-SNAPSHOT</version>
- <artifactId>scatours-tripbooking-contribution</artifactId>
+ <artifactId>scatours-contribution-tripbooking</artifactId>
<name>Apache Tuscany SCA Tours Trip Booking Contribution</name>
<dependencies>
@@ -43,19 +43,19 @@
<dependency>
<groupId>org.apache.tuscany.sca</groupId>
- <artifactId>scatours-common-contribution</artifactId>
+ <artifactId>scatours-contribution-common</artifactId>
<version>1.0-SNAPSHOT</version>
</dependency>
<dependency>
<groupId>org.apache.tuscany.sca</groupId>
- <artifactId>scatours-currency-contribution</artifactId>
+ <artifactId>scatours-contribution-currency</artifactId>
<version>1.0-SNAPSHOT</version>
</dependency>
<dependency>
<groupId>org.apache.tuscany.sca</groupId>
- <artifactId>scatours-shoppingcart-contribution</artifactId>
+ <artifactId>scatours-contribution-shoppingcart</artifactId>
<version>1.0-SNAPSHOT</version>
</dependency>
diff --git a/sandbox/travelsample/contributions/tripbooking-contribution/src/main/java/scatours/tripbooking/TripBooking.java b/sandbox/travelsample/contributions/tripbooking/src/main/java/com/tuscanyscatours/tripbooking/TripBooking.java
index 8959bc29f3..f866c6208f 100644
--- a/sandbox/travelsample/contributions/tripbooking-contribution/src/main/java/scatours/tripbooking/TripBooking.java
+++ b/sandbox/travelsample/contributions/tripbooking/src/main/java/com/tuscanyscatours/tripbooking/TripBooking.java
@@ -16,14 +16,14 @@
* specific language governing permissions and limitations
* under the License.
*/
-package scatours.tripbooking;
+package com.tuscanyscatours.tripbooking;
import org.osoa.sca.annotations.Remotable;
-import scatours.common.TripItem;
+import com.tuscanyscatours.common.TripItem;
/**
- * The Trip service interface
+ * The TripBooking service interface
*/
@Remotable
public interface TripBooking {
diff --git a/sandbox/travelsample/contributions/tripbooking/src/main/resources/META-INF/sca-contribution.xml b/sandbox/travelsample/contributions/tripbooking/src/main/resources/META-INF/sca-contribution.xml
new file mode 100644
index 0000000000..906f892d1f
--- /dev/null
+++ b/sandbox/travelsample/contributions/tripbooking/src/main/resources/META-INF/sca-contribution.xml
@@ -0,0 +1,26 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+-->
+<contribution xmlns="http://www.osoa.org/xmlns/sca/1.0">
+ <import.java package="com.tuscanyscatours.common" />
+ <import.java package="com.tuscanyscatours.currencyconverter" />
+ <import.java package="com.tuscanyscatours.shoppingcart" />
+ <export.java package="com.tuscanyscatours.tripbooking" />
+ <export.java package="com.tuscanyscatours.tripbooking.impl" />
+</contribution>
diff --git a/sandbox/travelsample/contributions/tripbooking-contribution/src/main/java/scatours/tripbooking/TripBookingImpl.java b/sandbox/travelsample/contributions/tripbooking/src/main/java/com/tuscanyscatours/tripbooking/impl/TripBookingImpl.java
index debbafda64..6d66a1ec45 100644
--- a/sandbox/travelsample/contributions/tripbooking-contribution/src/main/java/scatours/tripbooking/TripBookingImpl.java
+++ b/sandbox/travelsample/contributions/tripbooking/src/main/java/com/tuscanyscatours/tripbooking/impl/TripBookingImpl.java
@@ -16,7 +16,7 @@
* specific language governing permissions and limitations
* under the License.
*/
-package scatours.tripbooking;
+package com.tuscanyscatours.tripbooking.impl;
import org.osoa.sca.ComponentContext;
import org.osoa.sca.ServiceReference;
@@ -24,12 +24,13 @@ import org.osoa.sca.annotations.Context;
import org.osoa.sca.annotations.Reference;
import org.osoa.sca.annotations.Service;
-import scatours.common.Book;
-import scatours.common.TripItem;
-import scatours.shoppingcart.ShoppingCart;
+import com.tuscanyscatours.common.Book;
+import com.tuscanyscatours.common.TripItem;
+import com.tuscanyscatours.shoppingcart.ShoppingCart;
+import com.tuscanyscatours.tripbooking.TripBooking;
/**
* An implementation of the Trip service
*/
@Service(interfaces={TripBooking.class})
public class TripBookingImpl implements TripBooking{
@@ -24,12 +24,13 @@ import org.osoa.sca.annotations.Context;
/**
- * An implementation of the Trip service
+ * An implementation of the TripBooking service
*/